package de.intevation.flys.artifacts.states;

import org.apache.log4j.Logger;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public abstract class RangeState extends DefaultState {

    /** The logger that is used in this class.*/
    private static Logger logger = Logger.getLogger(RangeState.class);


    public RangeState() {
    }


    /**
     * Validates a given range with a given valid range.
     *
     * @param fromValid Valid lower value of the range.
     * @param toValid Valid upper value of the range.
     * @param from The lower value.
     * @param to The upper value.
     * @param step The step width.
     *
     * @return true, if everything was fine, otherwise an exception is thrown.
     */
    protected boolean validateRange(
        double fromValid, double toValid,
        double from,      double to,      double step)
    throws IllegalArgumentException
    {
        logger.debug("RangeState.validateRange");

        if (from < fromValid) {
            logger.error(
                "Invalid 'from'. " + from + " is smaller than " + fromValid);
            throw new IllegalArgumentException("error_feed_from_out_of_range");
        }
        else if (to > toValid) {
            logger.error(
                "Invalid 'to'. " + to + " is bigger than " + toValid);
            throw new IllegalArgumentException("error_feed_to_out_of_range");
        }
        else if (from > to) {
            throw new IllegalArgumentException("error_feed_from_bigger_to");
        }

        return true;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
